fireworks.core.tests package — FireWorks 1.4.4 documentation

# fireworks.core.tests package

## Submodules

## fireworks.core.tests.tasks module

class `fireworks.core.tests.tasks.` `ExceptionTestTask`(*args, **kwargs)

  Bases: `fireworks.core.firework.FiretaskBase`

  `exec_counter` = 0
  `run_task`(fw_spec)

class `fireworks.core.tests.tasks.` `ExecutionCounterTask`(*args, **kwargs)

  Bases: `fireworks.core.firework.FiretaskBase`

  `exec_counter` = 0
  `run_task`(fw_spec)

class `fireworks.core.tests.tasks.` `MalformedAdditionTask`(*args, **kwargs)

  Bases: `fireworks.core.firework.FiretaskBase`

  `run_task`(fw_spec)

exception `fireworks.core.tests.tasks.` `SerializableException`(exc_details)

  Bases: `exceptions.Exception`

  `to_dict`()

class `fireworks.core.tests.tasks.` `SlowAdditionTask`(*args, **kwargs)

  Bases: `fireworks.core.firework.FiretaskBase`

  `run_task`(fw_spec)

class `fireworks.core.tests.tasks.` `SlowTodictTask`(*args, **kwargs)

  Bases: `fireworks.core.firework.FiretaskBase`

  `run_task`(fw_spec)
  `to_dict`()

class `fireworks.core.tests.tasks.` `TodictErrorTask`(*args, **kwargs)

  Bases: `fireworks.core.firework.FiretaskBase`

  `run_task`(fw_spec)
  `to_dict`()

class `fireworks.core.tests.tasks.` `WaitWFLockTask`(*args, **kwargs)

  Bases: `fireworks.core.firework.FiretaskBase`

  `run_task`(fw_spec)

## fireworks.core.tests.test_firework module

class `fireworks.core.tests.test_firework.` `FiretaskBaseTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `test_init`()

class `fireworks.core.tests.test_firework.` `Task1`(*args, **kwargs)

  Bases: `fireworks.core.firework.FiretaskBase`

  `run_task`(fw_spec)

class `fireworks.core.tests.test_firework.` `Task2`(*args, **kwargs)

  Bases: `fireworks.core.firework.FiretaskBase`

  `run_task`(fw_spec)

class `fireworks.core.tests.test_firework.` `WorkflowTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()
  `test_copy`()

    Test that we can produce a copy of a Workflow but that the copy has unique fw_ids.

  `test_init`()
  `test_remove_leaf_fws`()
  `test_remove_root_fws`()

## fireworks.core.tests.test_launchpad module

class `fireworks.core.tests.test_launchpad.` `LaunchPadDefuseReigniteRerunArchiveDeleteTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()
  classmethod `setUpClass`()
  `tearDown`()
  classmethod `tearDownClass`()
  `test_archive_wf`()
  `test_defuse_fw`()
  `test_defuse_fw_after_completion`()
  `test_defuse_wf`()
  `test_defuse_wf_after_partial_run`()
  `test_delete_wf`()
  `test_pause_fw`()
  `test_pause_wf`()
  `test_reignite_fw`()
  `test_reignite_wf`()
  `test_rerun_fws2`()

class `fireworks.core.tests.test_launchpad.` `LaunchPadLostRunsDetectTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()
  classmethod `setUpClass`()
  `tearDown`()
  classmethod `tearDownClass`()
  `test_detect_lostruns`()
  `test_detect_lostruns_defuse`()
  `test_state_after_run_start`()

class `fireworks.core.tests.test_launchpad.` `LaunchPadOfflineTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()
  classmethod `setUpClass`()
  `tearDown`()
  classmethod `tearDownClass`()
  `test__recover_completed`()
  `test_recover_errors`()

class `fireworks.core.tests.test_launchpad.` `LaunchPadRerunExceptionTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()
  classmethod `setUpClass`()
  `tearDown`()
  classmethod `tearDownClass`()
  `test_except_details_on_rerun`()
  `test_task_level_rerun`()
  `test_task_level_rerun_cp`()
  `test_task_level_rerun_prev_dir`()

class `fireworks.core.tests.test_launchpad.` `LaunchPadTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()
  classmethod `setUpClass`()
  `tearDown`()
  classmethod `tearDownClass`()
  `test_add_wf`()
  `test_dict_from_file`()
  `test_pw_check`()
  `test_reset`()

class `fireworks.core.tests.test_launchpad.` `WFLockTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()
  classmethod `setUpClass`()
  `tearDown`()
  classmethod `tearDownClass`()
  `test_fix_db_inconsistencies_completed`()
  `test_fix_db_inconsistencies_fizzled`()

class `fireworks.core.tests.test_launchpad.` `WorkflowFireworkStatesTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Class to test the firework states locally cached in workflow. The states have to be in sync with the actual firework state.

  `setUp`()
  classmethod `setUpClass`()
  `tearDown`()
  classmethod `tearDownClass`()
  `test_archive_wf`()
  `test_defuse_fw`()
  `test_defuse_fw_after_completion`()
  `test_defuse_wf`()
  `test_reignite_fw`()
  `test_reignite_wf`()
  `test_rerun_fws`()
  `test_rerun_timed_fws`()

## fireworks.core.tests.test_rocket module

class `fireworks.core.tests.test_rocket.` `RocketTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()
  classmethod `setUpClass`()
  `tearDown`()
  classmethod `tearDownClass`()
  `test_postproc_exception`()
  `test_serializable_exception`()

## fireworks.core.tests.test_tracker module

class `fireworks.core.tests.test_tracker.` `TrackerTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()
  classmethod `setUpClass`()
  `tearDown`()
  classmethod `tearDownClass`()
  `test_tracker`()

    Launch a workflow and track the files

  `test_tracker_failed_fw`()

    Add a bad firetask to workflow and test the tracking

  `test_tracker_mlaunch`()

    Test the tracker for mlaunch

## Module contents